#pragma once

#include <array>
#include <vulkan/vulkan.hpp>

#include "../core/types.hpp"

namespace config {

  // Window settings
  constexpr i32 WIDTH  = 1920;
  constexpr i32 HEIGHT = 1080;

  // Vulkan settings
  constexpr i32 MAX_FRAMES_IN_FLIGHT = 2;

  // Shader paths
  constexpr const char* VERTEX_SHADER_PATH   = "shaders/vertex.glsl";
  constexpr const char* FRAGMENT_SHADER_PATH = "shaders/fragment.glsl";

// Validation layers for debug builds
#ifndef NDEBUG
  constexpr std::array<const char*, 1> validationLayers = { "VK_LAYER_KHRONOS_validation" };
#endif

// Required device extensions (platform-specific)
#ifdef __APPLE__
  constexpr std::array<const char*, 2> deviceExtensions = { vk::KHRSwapchainExtensionName,
                                                            vk::KHRPortabilitySubsetExtensionName };
#else
  constexpr std::array<const char*, 1> deviceExtensions = { vk::KHRSwapchainExtensionName };
#endif

} // namespace config
